==> e107-0.7.20.tbz: www/e107/e107_plugins/list_new/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Steve Dunstan 2001-2002
|     http://e107.org
|     jalist@e107.org
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/list_new/languages/English.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/

if (!defined("PAGE_NAME")) { define("PAGE_NAME", "List New Items"); }

define("LIST_PLUGIN_1", "List");
define("LIST_PLUGIN_2", "This plugin allows you to view a list of recent additions in all e107 categories. You can either view the list with data since your last visit, or view a general latest additions list. Besides the page a menu is also present. Every section is configurable in the admin area.");
define("LIST_PLUGIN_3", "Configure Main Menu");
define("LIST_PLUGIN_4", "The List_new plugin is now ready to be used.");
define("LIST_PLUGIN_5", "list");
define("LIST_PLUGIN_6", "This plugin is not installed.");

define("LIST_ADMIN_1", "recent");
define("LIST_ADMIN_2", "update settings");
define("LIST_ADMIN_3", "settings updated");
define("LIST_ADMIN_4", "section");
define("LIST_ADMIN_5", "menu");
define("LIST_ADMIN_6", "page");
define("LIST_ADMIN_7", "enabled");
define("LIST_ADMIN_8", "disabled");
define("LIST_ADMIN_9", "open");
define("LIST_ADMIN_10", "closed");
define("LIST_ADMIN_11", "update");
define("LIST_ADMIN_12", "choose");
define("LIST_ADMIN_13", "Welcome to the Recent page of ".SITENAME." ! This page shows, for the most common sections of this site, a list of the most recent additions in these sections.");
define("LIST_ADMIN_14", "recent additions");
define("LIST_ADMIN_15", "new since your last visit");
define("LIST_ADMIN_16", "Welcome to the New page of ".SITENAME." ! This page shows, for the most common sections of this site, a list of the additions in these sections since your last visit.");

define("LIST_ADMIN_SECT_1", "sections");
define("LIST_ADMIN_SECT_2", "choose which sections to show");
define("LIST_ADMIN_SECT_3", "");

define("LIST_ADMIN_SECT_4", "display style");
define("LIST_ADMIN_SECT_5", "choose which sections are opened by default");
define("LIST_ADMIN_SECT_6", "");

define("LIST_ADMIN_SECT_7", "author");
define("LIST_ADMIN_SECT_8", "choose if the author should be displayed");
define("LIST_ADMIN_SECT_9", "");

define("LIST_ADMIN_SECT_10", "category");
define("LIST_ADMIN_SECT_11", "choose if the category should be displayed");
define("LIST_ADMIN_SECT_12", "");

define("LIST_ADMIN_SECT_13", "date");
define("LIST_ADMIN_SECT_14", "choose if the date should be displayed");
define("LIST_ADMIN_SECT_15", "");

define("LIST_ADMIN_SECT_16", "amount items");
define("LIST_ADMIN_SECT_17", "choose how many items should be displayed for each section");
define("LIST_ADMIN_SECT_18", "");

define("LIST_ADMIN_SECT_19", "order items");
define("LIST_ADMIN_SECT_20", "choose the order in which sections should be displayed");
define("LIST_ADMIN_SECT_21", "");

define("LIST_ADMIN_SECT_22", "icon");
define("LIST_ADMIN_SECT_23", "choose an icon for each section");
define("LIST_ADMIN_SECT_24", "");

define("LIST_ADMIN_SECT_25", "caption");
define("LIST_ADMIN_SECT_26", "define a caption for each section");
define("LIST_ADMIN_SECT_27", "");

define("LIST_ADMIN_OPT_1", "general");
define("LIST_ADMIN_OPT_2", "recent page");
define("LIST_ADMIN_OPT_3", "recent menu");
define("LIST_ADMIN_OPT_4", "new page");
define("LIST_ADMIN_OPT_5", "new menu");
define("LIST_ADMIN_OPT_6", "options");

define("LIST_ADMIN_MENU_2", "icon : default");
define("LIST_ADMIN_MENU_3", "use default theme bullet if no icon is present or if icon:use is disabled");
define("LIST_ADMIN_MENU_4", "");

define("LIST_ADMIN_LAN_2", "caption");
define("LIST_ADMIN_LAN_3", "define a caption");
define("LIST_ADMIN_LAN_4", "");

define("LIST_ADMIN_LAN_5", "icon : use");
define("LIST_ADMIN_LAN_6", "use icon from each section");
define("LIST_ADMIN_LAN_7", "");

define("LIST_ADMIN_LAN_8", "characters");
define("LIST_ADMIN_LAN_9", "choose how many characters of the heading will be shown");
define("LIST_ADMIN_LAN_10", "leave blank to show full heading");

define("LIST_ADMIN_LAN_11", "postfix");
define("LIST_ADMIN_LAN_12", "choose a postfix if the heading is larger then the given amount of characters");
define("LIST_ADMIN_LAN_13", "leave blank to show no postfix");

define("LIST_ADMIN_LAN_14", "date");
define("LIST_ADMIN_LAN_15", "choose a date style");
define("LIST_ADMIN_LAN_16", "For more information on date formats see the <a href='http://www.php.net/manual/en/function.strftime.php' rel='external'>strftime function page at php.net</a>");

define("LIST_ADMIN_LAN_17", "today date");
define("LIST_ADMIN_LAN_18", "choose a date style if the date is today");
define("LIST_ADMIN_LAN_19", "For more information on date formats see the <a href='http://www.php.net/manual/en/function.strftime.php' rel='external'>strftime function page at php.net</a>");

define("LIST_ADMIN_LAN_20", "columns");
define("LIST_ADMIN_LAN_21", "choose an amount of columns");
define("LIST_ADMIN_LAN_22", "define how many columns you want to use. the number you specify will separate the page into an equal amount of columns");

define("LIST_ADMIN_LAN_23", "welcome text");
define("LIST_ADMIN_LAN_24", "define a welcome text that will be rendered at the top of the page");
define("LIST_ADMIN_LAN_25", "");

define("LIST_ADMIN_LAN_26", "show empty");
define("LIST_ADMIN_LAN_27", "define if a message needs to be shown when sections have no results ");
define("LIST_ADMIN_LAN_28", "");

define("LIST_ADMIN_LAN_29", "icon : default");
define("LIST_ADMIN_LAN_30", "use default theme bullet if no icon is present or if icon:use is disabled");
define("LIST_ADMIN_LAN_31", "");

define("LIST_ADMIN_LAN_32", "timelapse:days");
define("LIST_ADMIN_LAN_33", "maximum of days users can look back");
define("LIST_ADMIN_LAN_34", "");
define("LIST_ADMIN_LAN_35", "days");

define("LIST_ADMIN_LAN_36", "timelapse");
define("LIST_ADMIN_LAN_37", "display a select box with number of days to look back?");
define("LIST_ADMIN_LAN_38", "");

define("LIST_ADMIN_LAN_39", "open if records exist");
define("LIST_ADMIN_LAN_40", "should sections that contain records be opened by default?");
define("LIST_ADMIN_LAN_41", "");

define("LIST_MENU_1", "recent additions");
define("LIST_MENU_2", "by");
define("LIST_MENU_3", "on");
define("LIST_MENU_4", "in");
define("LIST_MENU_5", "days");
define("LIST_MENU_6", "view content for how many days?");
define("LIST_MENU_7", "");
define("LIST_MENU_8", "");
define("LIST_MENU_9", "");
define("LIST_MENU_10", "");
define("LIST_MENU_11", "");
define("LIST_MENU_12", "");
define("LIST_MENU_13", "");
define("LIST_MENU_14", "");
define("LIST_MENU_15", "");
define("LIST_MENU_16", "");
define("LIST_MENU_17", "");
define("LIST_MENU_18", "");
define("LIST_MENU_19", "");

define("LIST_NEWS_1", "news");
define("LIST_NEWS_2", "no news items");

define("LIST_COMMENT_1", "comments");
define("LIST_COMMENT_2", "no comments");
define("LIST_COMMENT_3", "news");
define("LIST_COMMENT_4", "faq");
define("LIST_COMMENT_5", "poll");
define("LIST_COMMENT_6", "docs");
define("LIST_COMMENT_7", "bugtrack");
define("LIST_COMMENT_8", "content");
define("LIST_COMMENT_9", "download");
define("LIST_COMMENT_10", "ideas");

define("LIST_DOWNLOAD_1", "downloads");
define("LIST_DOWNLOAD_2", "no downloads");

define("LIST_MEMBER_1", "members");
define("LIST_MEMBER_2", "no members");

define("LIST_CONTENT_1", "content");
define("LIST_CONTENT_2", "no content in");
define("LIST_CONTENT_3", "no valid content category");

define("LIST_CHATBOX_1", "chatbox");
define("LIST_CHATBOX_2", "no chatbox posts");

define("LIST_CALENDAR_1", "calendar");
define("LIST_CALENDAR_2", "no calendar events");

define("LIST_LINKS_1", "links");
define("LIST_LINKS_2", "no links");

define("LIST_FORUM_1", "forum");
define("LIST_FORUM_2", "no forum posts");
define("LIST_FORUM_3", "views:");
define("LIST_FORUM_4", "replies:");
define("LIST_FORUM_5", "lastpost:");
define("LIST_FORUM_6", "on:");

?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/list_new/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Copyright (C) 2001-2002 Steve Dunstan (jalist@e107.org)
|     Copyright (C) 2008-2010 e107 Inc (e107.org)
|
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/list_new/languages/English.php $
|     $Revision: 11678 $
|     $Id: English.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/

if (!defined("PAGE_NAME")) { define("PAGE_NAME", "List New Items"); }

define("LIST_PLUGIN_1", "List");
define("LIST_PLUGIN_2", "This plugin allows you to view a list of recent additions in all e107 categories. You can either view the list with data since your last visit, or view a general latest additions list. Besides the page a menu is also present. Every section is configurable in the admin area.");
define("LIST_PLUGIN_3", "Configure Main Menu");
define("LIST_PLUGIN_4", "The List_new plugin is now ready to be used.");
define("LIST_PLUGIN_5", "list");
define("LIST_PLUGIN_6", "This plugin is not installed.");

define("LIST_ADMIN_1", "recent");
define("LIST_ADMIN_2", "update settings");
define("LIST_ADMIN_3", "settings updated");
define("LIST_ADMIN_4", "section");
define("LIST_ADMIN_5", "menu");
define("LIST_ADMIN_6", "page");
define("LIST_ADMIN_7", "enabled");
define("LIST_ADMIN_8", "disabled");
define("LIST_ADMIN_9", "open");
define("LIST_ADMIN_10", "closed");
define("LIST_ADMIN_11", "update");
define("LIST_ADMIN_12", "choose");
define("LIST_ADMIN_13", "Welcome to the Recent page of ".SITENAME." ! This page shows, for the most common sections of this site, a list of the most recent additions in these sections.");
define("LIST_ADMIN_14", "recent additions");
define("LIST_ADMIN_15", "new since your last visit");
define("LIST_ADMIN_16", "Welcome to the New page of ".SITENAME." ! This page shows, for the most common sections of this site, a list of the additions in these sections since your last visit.");

define("LIST_ADMIN_SECT_1", "sections");
define("LIST_ADMIN_SECT_2", "choose which sections to show");
define("LIST_ADMIN_SECT_3", "");

define("LIST_ADMIN_SECT_4", "display style");
define("LIST_ADMIN_SECT_5", "choose which sections are opened by default");
define("LIST_ADMIN_SECT_6", "");

define("LIST_ADMIN_SECT_7", "author");
define("LIST_ADMIN_SECT_8", "choose if the author should be displayed");
define("LIST_ADMIN_SECT_9", "");

define("LIST_ADMIN_SECT_10", "category");
define("LIST_ADMIN_SECT_11", "choose if the category should be displayed");
define("LIST_ADMIN_SECT_12", "");

define("LIST_ADMIN_SECT_13", "date");
define("LIST_ADMIN_SECT_14", "choose if the date should be displayed");
define("LIST_ADMIN_SECT_15", "");

define("LIST_ADMIN_SECT_16", "amount items");
define("LIST_ADMIN_SECT_17", "choose how many items should be displayed for each section");
define("LIST_ADMIN_SECT_18", "");

define("LIST_ADMIN_SECT_19", "order items");
define("LIST_ADMIN_SECT_20", "choose the order in which sections should be displayed");
define("LIST_ADMIN_SECT_21", "");

define("LIST_ADMIN_SECT_22", "icon");
define("LIST_ADMIN_SECT_23", "choose an icon for each section");
define("LIST_ADMIN_SECT_24", "");

define("LIST_ADMIN_SECT_25", "caption");
define("LIST_ADMIN_SECT_26", "define a caption for each section");
define("LIST_ADMIN_SECT_27", "");

define("LIST_ADMIN_OPT_1", "general");
define("LIST_ADMIN_OPT_2", "recent page");
define("LIST_ADMIN_OPT_3", "recent menu");
define("LIST_ADMIN_OPT_4", "new page");
define("LIST_ADMIN_OPT_5", "new menu");
define("LIST_ADMIN_OPT_6", "options");

define("LIST_ADMIN_MENU_2", "icon : default");
define("LIST_ADMIN_MENU_3", "use default theme bullet if no icon is present or if icon:use is disabled");
define("LIST_ADMIN_MENU_4", "");

define("LIST_ADMIN_LAN_2", "caption");
define("LIST_ADMIN_LAN_3", "define a caption");
define("LIST_ADMIN_LAN_4", "");

define("LIST_ADMIN_LAN_5", "icon : use");
define("LIST_ADMIN_LAN_6", "use icon from each section");
define("LIST_ADMIN_LAN_7", "");

define("LIST_ADMIN_LAN_8", "characters");
define("LIST_ADMIN_LAN_9", "choose how many characters of the heading will be shown");
define("LIST_ADMIN_LAN_10", "leave blank to show full heading");

define("LIST_ADMIN_LAN_11", "postfix");
define("LIST_ADMIN_LAN_12", "choose a postfix if the heading is larger then the given amount of characters");
define("LIST_ADMIN_LAN_13", "leave blank to show no postfix");

define("LIST_ADMIN_LAN_14", "date");
define("LIST_ADMIN_LAN_15", "choose a date style");
define("LIST_ADMIN_LAN_16", "For more information on date formats see the <a href='http://www.php.net/manual/en/function.strftime.php' rel='external'>strftime function page at php.net</a>");

define("LIST_ADMIN_LAN_17", "today date");
define("LIST_ADMIN_LAN_18", "choose a date style if the date is today");
define("LIST_ADMIN_LAN_19", "For more information on date formats see the <a href='http://www.php.net/manual/en/function.strftime.php' rel='external'>strftime function page at php.net</a>");

define("LIST_ADMIN_LAN_20", "columns");
define("LIST_ADMIN_LAN_21", "choose an amount of columns");
define("LIST_ADMIN_LAN_22", "define how many columns you want to use. the number you specify will separate the page into an equal amount of columns");

define("LIST_ADMIN_LAN_23", "welcome text");
define("LIST_ADMIN_LAN_24", "define a welcome text that will be rendered at the top of the page");
define("LIST_ADMIN_LAN_25", "");

define("LIST_ADMIN_LAN_26", "show empty");
define("LIST_ADMIN_LAN_27", "define if a message needs to be shown when sections have no results ");
define("LIST_ADMIN_LAN_28", "");

define("LIST_ADMIN_LAN_29", "icon : default");
define("LIST_ADMIN_LAN_30", "use default theme bullet if no icon is present or if icon:use is disabled");
define("LIST_ADMIN_LAN_31", "");

define("LIST_ADMIN_LAN_32", "timelapse:days");
define("LIST_ADMIN_LAN_33", "maximum of days users can look back");
define("LIST_ADMIN_LAN_34", "");
define("LIST_ADMIN_LAN_35", "days");

define("LIST_ADMIN_LAN_36", "timelapse");
define("LIST_ADMIN_LAN_37", "display a select box with number of days to look back?");
define("LIST_ADMIN_LAN_38", "");

define("LIST_ADMIN_LAN_39", "open if records exist");
define("LIST_ADMIN_LAN_40", "should sections that contain records be opened by default?");
define("LIST_ADMIN_LAN_41", "");

define("LIST_MENU_1", "recent additions");
define("LIST_MENU_2", "by");
define("LIST_MENU_3", "on");
define("LIST_MENU_4", "in");
define("LIST_MENU_5", "days");
define("LIST_MENU_6", "view content for how many days?");
define("LIST_MENU_7", "");
define("LIST_MENU_8", "");
define("LIST_MENU_9", "");
define("LIST_MENU_10", "");
define("LIST_MENU_11", "");
define("LIST_MENU_12", "");
define("LIST_MENU_13", "");
define("LIST_MENU_14", "");
define("LIST_MENU_15", "");
define("LIST_MENU_16", "");
define("LIST_MENU_17", "");
define("LIST_MENU_18", "");
define("LIST_MENU_19", "");

define("LIST_NEWS_1", "news");
define("LIST_NEWS_2", "no news items");

define("LIST_COMMENT_1", "comments");
define("LIST_COMMENT_2", "no comments");
define("LIST_COMMENT_3", "news");
define("LIST_COMMENT_4", "faq");
define("LIST_COMMENT_5", "poll");
define("LIST_COMMENT_6", "docs");
define("LIST_COMMENT_7", "bugtrack");
define("LIST_COMMENT_8", "content");
define("LIST_COMMENT_9", "download");
define("LIST_COMMENT_10", "ideas");

define("LIST_DOWNLOAD_1", "downloads");
define("LIST_DOWNLOAD_2", "no downloads");

define("LIST_MEMBER_1", "members");
define("LIST_MEMBER_2", "no members");

define("LIST_CONTENT_1", "content");
define("LIST_CONTENT_2", "no content in");
define("LIST_CONTENT_3", "no valid content category");

define("LIST_CHATBOX_1", "chatbox");
define("LIST_CHATBOX_2", "no chatbox posts");

define("LIST_CALENDAR_1", "calendar");
define("LIST_CALENDAR_2", "no calendar events");

define("LIST_LINKS_1", "links");
define("LIST_LINKS_2", "no links");

define("LIST_FORUM_1", "forum");
define("LIST_FORUM_2", "no forum posts");
define("LIST_FORUM_3", "views:");
define("LIST_FORUM_4", "replies:");
define("LIST_FORUM_5", "lastpost:");
define("LIST_FORUM_6", "on:");

?>
